* EmployerPenaltyExhibits.do  11/12/17
* Tables 3, 4, 6 and Figures 3, 4a

set more off
use "Public Raw Data for ACA Small Business Study – Mercatus.dta", clear

* (1) create variables for analysis
label define eversponsored 0 "No" 1 "Yes, more than five years ago" 2 "Yes, three to five years ago" 3 "Yes, one to two years ago" 4 "Yes, within the past year"
encode Q3_4, generate(Q3_4_enc) label(eversponsored)
label define beginoffer 0 "Less than 6 months ago" 1 "6 to 12 months ago" 2 "Between 1 and 2 years ago" 3 "Between 2 and 3 years ago" 4 "Between 3 and 5 years ago" 5 "Over 5 years ago"
encode Q3_5, generate(Q3_5_enc) label(beginoffer)
label define employees 1 "2-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8 "35-39" 9 "40-49" 10 "50-74" 11 "75-99" 12 "100-149" 13 "150-199"
encode Q1_8, generate(Q1_8_enc) label(employees)
encode Q1_9, generate(Q1_9_enc) label(employees)
label define ptemployees 0 "None" 1 "1-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8 "35-39" 9 "40-49" 10 "50-74" 11 "75-99" 12 "100-149" 13 "150-199" 14 "200+ employees"
encode Q1_10, generate(Q1_10_enc) label(ptemployees)

gen byte esi = Q3_2_Employer_sponsored_private==1 | Q3_2_Employer_sponsored_SHOP==1
gen byte esipreACA = (esi==1 & Q3_5_enc>3) | (esi==0 & Q3_4_enc>0)
gen byte esidropped2017 = Q3_4_enc==4

gen byte reducinghiringcounting = (Q5_13_Yes_reducing_hours_new==1) + (Q5_13_Yes_reducing_hours_existin==1) + (Q5_13_Yes_more_PT_than_FT_hires==1) + (Q5_13_Yes_hiring_fewer_employees==1)
gen byte reducinghiringindicator = (Q5_13_Yes_reducing_hours_new==1) | (Q5_13_Yes_reducing_hours_existin==1) | (Q5_13_Yes_more_PT_than_FT_hires==1) | (Q5_13_Yes_hiring_fewer_employees==1)

gen byte numotherfringes = (Q3_2_Employer_401K_matching==1) + (Q3_2_Vision_insurance==1) + ( Q3_2_Dental_insurance==1) + (Q3_2_Paid_maternity_leave==1) + ( Q3_2_Short_term_disability==1) + (Q3_2_Long_term_disability==1) + ( Q3_2_Life_insurance==1) + (Q3_2_Commuter_benefits==1) + (Q3_2_Childcare_benefits==1)
gen byte numonodental = (Q3_2_Employer_401K_matching==1) + (Q3_2_Vision_insurance==1) + (Q3_2_Paid_maternity_leave==1) + ( Q3_2_Short_term_disability==1) + (Q3_2_Long_term_disability==1) + ( Q3_2_Life_insurance==1) + (Q3_2_Commuter_benefits==1) + (Q3_2_Childcare_benefits==1)
gen byte dental = (Q3_2_Dental_insurance==1)
gen byte in3034 = Q1_8_enc==7
gen byte in3539 = Q1_8_enc==8
gen byte in4049 = Q1_8_enc==9
gen byte in3034ly = Q1_9_enc==7
gen byte in3539ly = Q1_9_enc==8
gen byte in4049ly = Q1_9_enc==9
encode Q1_2, gen(indcode)

* (2) estimate total employment (for weighting purposes)
* (2.a) FT
gen numftly = 3 if Q1_9_enc==1
replace numftly = 7 if Q1_9_enc==2
replace numftly = 12 if Q1_9_enc==3
replace numftly = 17 if Q1_9_enc==4
replace numftly = 22 if Q1_9_enc==5
replace numftly = 27 if Q1_9_enc==6
replace numftly = 32 if Q1_9_enc==7
replace numftly = 37 if Q1_9_enc==8
replace numftly = 44.5 if Q1_9_enc==9
replace numftly = 62 if Q1_9_enc==10
replace numftly = 87 if Q1_9_enc==11
replace numftly = 124.5 if Q1_9_enc==12
replace numftly = 174.5 if Q1_9_enc==13
* (2.b) PT
gen numptly = 0 if Q1_10_enc==0
replace numptly = 2.5 if Q1_10_enc==1
replace numptly = 7 if Q1_10_enc==2
replace numptly = 12 if Q1_10_enc==3
replace numptly = 17 if Q1_10_enc==4
replace numptly = 22 if Q1_10_enc==5
replace numptly = 27 if Q1_10_enc==6
replace numptly = 32 if Q1_10_enc==7
replace numptly = 37 if Q1_10_enc==8
replace numptly = 44.5 if Q1_10_enc==9
replace numptly = 62 if Q1_10_enc==10
replace numptly = 87 if Q1_10_enc==11
replace numptly = 124.5 if Q1_10_enc==12
replace numptly = 174.5 if Q1_10_enc==13
replace numptly = 220 if Q1_10_enc==14
gen totalemply = numptly + numftly

* (3) merge in probability estimates
gen int ftlow = 2 if Q1_9_enc==1
replace ftlow = 5 if Q1_9_enc==2
replace ftlow = 10 if Q1_9_enc==3
replace ftlow = 15 if Q1_9_enc==4
replace ftlow = 20 if Q1_9_enc==5
replace ftlow = 25 if Q1_9_enc==6
replace ftlow = 30 if Q1_9_enc==7
replace ftlow = 35 if Q1_9_enc==8
replace ftlow = 40 if Q1_9_enc==9
replace ftlow = 50 if Q1_9_enc==10
replace ftlow = 75 if Q1_9_enc==11
replace ftlow = 100 if Q1_9_enc==12
replace ftlow = 150 if Q1_9_enc==13
gen int ptlow = 0 if Q1_10_enc==0
replace ptlow = 1 if Q1_10_enc==1
replace ptlow = 5 if Q1_10_enc==2
replace ptlow = 10 if Q1_10_enc==3
replace ptlow = 15 if Q1_10_enc==4
replace ptlow = 20 if Q1_10_enc==5
replace ptlow = 25 if Q1_10_enc==6
replace ptlow = 30 if Q1_10_enc==7
replace ptlow = 35 if Q1_10_enc==8
replace ptlow = 40 if Q1_10_enc==9
replace ptlow = 50 if Q1_10_enc==10
replace ptlow = 75 if Q1_10_enc==11
replace ptlow = 100 if Q1_10_enc==12
replace ptlow = 150 if Q1_10_enc==13
replace ptlow = 200 if Q1_10_enc==14
sort ftlow ptlow
merge ftlow ptlow using LikelyFTEs
tab _merge
drop if _merge<3
drop _merge
ren prfte3050 prfte3050ly
ren prfte4050 prfte4050ly
ren prfte5075 prfte5075ly

* (4) Table 4.  The propensity to offer ESI by employer size
* OLS
reg esi in3034 in3539 in4049 numotherfringes Q1_13 i.indcode
* TSLS1
ivregress 2sls esi numotherfringes Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
ivregress 2sls esi numonodental Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numonodental Q1_13 i.indcode)
ivregress 2sls esi numonodental dental Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numonodental dental Q1_13 i.indcode)
* TSLS2
ivregress 2sls esi numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
* TSLS3
ivregress 2sls esi numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly numotherfringes Q1_13 i.indcode)
* ESI in 2013
ivregress 2sls esipreACA numotherfringes Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
ivregress 2sls esipreACA numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly numotherfringes Q1_13 i.indcode)
* Drop ESI in 2017
ivregress 2sls esidropped numotherfringes Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)

* (5) Table 6.  Employer reports of the ACA's impact, by employer size
* OLS
reg reducinghiringcounting in3034 in3539 in4049 numotherfringes Q1_13 i.indcode
* TSLS1
ivregress 2sls reducinghiringcounting numotherfringes Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
* TSLS2
ivregress 2sls reducinghiringcounting numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
* TSLS3
ivregress 2sls reducinghiringcounting numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly numotherfringes Q1_13 i.indcode)
* TSLS1
ivregress 2sls reducinghiringindicator numotherfringes Q1_13 i.indcode (prfte3050ly=in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
* TSLS2
ivregress 2sls reducinghiringindicator numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly in3034 in3539 in4049 numotherfringes Q1_13 i.indcode)
* TSLS3
ivregress 2sls reducinghiringindicator numotherfringes Q1_13 i.indcode (prfte3050ly=in3034ly in3539ly in4049ly numotherfringes Q1_13 i.indcode)


* (6) Table 3.  The propensity to offer ESI in various subsamples
set more on
gen byte esipastyr = esi | Q3_4_enc==4
tab esi
tab esi [aw=1/totalemply]
tab esi if esipreACA==0
tab esi if esipreACA==0 [aw=1/totalemply]
tab esipreACA if esi==0
tab esipreACA if esi==0 [aw=1/totalemply]
tab esipreACA
tab esipreACA [aw=1/totalemply]

tab esi esipastyr, cell nof
tab esi esipastyr [aw=1/totalemply], cell nof

* (7) Figure 4a.  Respondent job titles
graph pie , over(Q1_3) plabel(_all name) legend(off) graphregion(color(white)) title("Figure 4a.  Which of the following comes closest to your title?") note("Administrative support was also an option.  It results in survey termination.")

* (8) Figure 3.  Non-ESI firms stay below 50
collapse (mean) esi Q1_8_enc numotherfringes Q1_13, by(Q1_8)
label var Q1_8_enc "Number of full-time employees"
label var esi "Share offering ESI"
label var numo "Avg number of other fringes"
twoway (bar esi Q1_8_enc, title("Figure 3.  Non-ESI firms stay below 50") subtitle("ESI firms do not") xlabel(1 "2-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8 "35-39" 9 "40-49" 10 "50-74" 11 "75-99" 12 "100-49" 13 "150-99",labsize(small)) barw(0.7)) || (line numo Q1_8_enc, xlabel(1 "2-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8 "35-39" 9 "40-49" 10 "50-74" 11 "75-99" 12 "100-49" 13 "150-99",labsize(small)) sort yaxis(2) yscale(range(1 5) axis(2)) graphregion(color(white)) legend(region(lstyle(none) lcolor(white))) ylabel(,nogrid))
